You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by br...@apache.org on 2013/05/07 20:37:21 UTC

svn commit: r1480009 - /subversion/trunk/tools/dev/build-svn-deps-win.pl

Author: breser
Date: Tue May  7 18:37:21 2013
New Revision: 1480009

URL: http://svn.apache.org/r1480009
Log:
Fix some build issues with support projects failing due to shared intermediate
build directories.

* tools/dev/build-svn-deps-win.pl:
  (build_openssl): Remove some tabs on some comment lines.
  (build_httpd): Use a different backup dir for disabling the
    manifest for ApacheMonitor project so it does not conflict
    with the TrackFileAccess change.  Add the support directory
    to the list of directories that we disable file access tracking
    on.

Modified:
    subversion/trunk/tools/dev/build-svn-deps-win.pl

Modified: subversion/trunk/tools/dev/build-svn-deps-win.pl
URL: http://svn.apache.org/viewvc/subversion/trunk/tools/dev/build-svn-deps-win.pl?rev=1480009&r1=1480008&r2=1480009&view=diff
==============================================================================
--- subversion/trunk/tools/dev/build-svn-deps-win.pl (original)
+++ subversion/trunk/tools/dev/build-svn-deps-win.pl Tue May  7 18:37:21 2013
@@ -481,8 +481,8 @@ sub build_openssl {
   # remove the no-asm below and use ms\do_nasm.bat instead.
   
   # TODO: Enable openssl to use zlib.  openssl needs some patching to do
-	# this since it wants to look for zlib as zlib1.dll and as the httpd
-	# build instructions note you probably don't want to dynamic link zlib.
+  # this since it wants to look for zlib as zlib1.dll and as the httpd
+  # build instructions note you probably don't want to dynamic link zlib.
   
   # TODO: OpenSSL requires perl on the path since it uses perl without a full
   # path in the batch file and the makefiles.  Probably should determine
@@ -647,17 +647,18 @@ sub build_httpd {
   # ApacheMonitor build fails due a duplicate manifest, turn off
   # GenerateManifest
   insert_property_group('support\win32\ApacheMonitor.vcxproj',
-                        '<GenerateManifest>false</GenerateManifest>');
+                        '<GenerateManifest>false</GenerateManifest>',
+                        '.dupman');
 
   # Modules randomly fail due to an error about the CL.read.1.tlog file
   # already existing.  This is really because of the intermediate dirs
   # being shared between modules, but for the time being this works around
   # it.
   find(sub {
          if (/\.vcxproj$/) {
            insert_property_group($_, '<TrackFileAccess>false</TrackFileAccess>')
          }
-       }, 'modules');
+       }, 'modules', 'support');
 
   # The APR libraries have projects named libapr but produce output named libapr-1
   # The problem with this is in newer versions of Visual Studio TargetName defaults
@@ -647,17 +647,18 @@ sub build_httpd {
 
-  # Modules randomly fail due to an error about the CL.read.1.tlog file
-  # already existing.  This is really because of the intermediate dirs
-  # being shared between modules, but for the time being this works around
-  # it.
+  # Modules and support projects randomly fail due to an error about the
+  # CL.read.1.tlog file already existing.  This is really because of the
+  # intermediate dirs being shared between modules, but for the time being
+  # this works around it.
   find(sub {
          if (/\.vcxproj$/) {